@@ -4,7 +4,7 @@ use 5.008_001;
 use strict;
 #use warnings;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use XSLoader;
 XSLoader::load(__PACKAGE__, $VERSION);
@@ -14,11 +14,11 @@ __END__
 
 =head1 NAME
 
-Scalar::Alias - Perl extention to declare lexical aliases
+Scalar::Alias - Perl extention to declare lexical scalar aliases
 
 =head1 VERSION
 
-This document describes Scalar::Alias version 0.04.
+This document describes Scalar::Alias version 0.05.
 
 =head1 SYNOPSIS
 
@@ -34,13 +34,23 @@ This document describes Scalar::Alias version 0.04.
 	inc($i);
 	print $i, "\n"; # => 1
 
+	my %h;
+	my alias $foo = $h{foo};
+
+	# %h is empty
+
+	$foo = 10;
+
+	# %h is {foo => 10}
+
+
 =head1 DESCRIPTION
 
-Scalar::Alias allows you to declare lexical aliases.
+Scalar::Alias allows you to declare lexical scalar aliases.
 
 There are many modules that provides variable aliases, but this module is
 faster than any other alias modules, because it walks into compiled syntax
-trees and inserts custom alias opcodes into the syntax tree.
+trees and inserts custom opcodes into the syntax tree in order to alias variables.
 
 =head1 DEPENDENCIES
 
@@ -54,7 +64,7 @@ Please report any bugs or feature requests to the author.
 
 =head1 SEE ALSO
 
-L<Scalar::Types>.
+L<Lexical::Types>.
 
 L<perltodo/"lexical aliases">.
 
@@ -70,6 +80,8 @@ L<Tie::Alias>.
 
 L<Variable::Alias>.
 
+L<Data::Alias>.
+
 =head1 AUTHOR
 
 Goro Fuji (gfx) E<lt>gfuji(at)cpan.orgE<gt>.
